# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

<!-- insertion marker -->

## [v0.0.1](https://github.com/b-lab-io/pyarazzo/releases/tag/v0.0.1) - 2026-01-18

<small>[Compare with first commit](https://github.com/b-lab-io/pyarazzo/compare/6f40108878e3ecaa184563d975bdfd10a1330bb5...0.1.0)</small>

### Features

- add doc command ([8b1df2b](https://github.com/b-lab-io/pyarazzo/commit/8b1df2b8944ad8962000b4c71eb3364c48fa313d) by Sebastien).
- initial walkthrough ([5d496a2](https://github.com/b-lab-io/pyarazzo/commit/5d496a2ea32dd216d2b8d78bc95ed7d1ddf9c8a3) by Sebastien).

### Bug Fixes

- missing dependency ([7179ba9](https://github.com/b-lab-io/pyarazzo/commit/7179ba940b289802cde65d340852d48ec61f69c9) by Sebastien).
- code quality ([6ae6d03](https://github.com/b-lab-io/pyarazzo/commit/6ae6d036e13361e98b05dbdb6ae021c88c025e5c) by Sebastien).
- add ruff exception to duties.py ([1e990ae](https://github.com/b-lab-io/pyarazzo/commit/1e990ae2c3fc9b15c1d2a51f3631b9e557a8a2e1) by Sebastien).
- installation ([64cbe98](https://github.com/b-lab-io/pyarazzo/commit/64cbe988153fdea1dadf12b5b096b7e475750d33) by Sebastien).
- ci code quality ([d9ecb69](https://github.com/b-lab-io/pyarazzo/commit/d9ecb691a7788be697cfa5e4c3fe20ab4d445cc1) by Sebastien).
- fix code quality and secure coding ([1d4fb47](https://github.com/b-lab-io/pyarazzo/commit/1d4fb473b3f01f6574daff63274a18c872e17c60) by Sebastien).
- path for temp file for windows tests ([b33820b](https://github.com/b-lab-io/pyarazzo/commit/b33820b6d6143ef0e909d8adfbef77e7695568dc) by Sebastien).
